#pragma semicolon 1

#include <vip>
#include <sourcemod>
#include <sdktools>

public Plugin:myinfo = 
{
	name	= "VIP [Jumps + parachute]",
	author	= "wS",
	version = "1.5.7"
};

#include "vip_jumps_parachute/vars.sp"
#include "vip_jumps_parachute/functions.sp"
#include "vip_jumps_parachute/vars_server.sp"
#include "vip_jumps_parachute/RunCmd.sp"

public OnPluginStart()
{
	//
	new bool:ok = false;
	new Handle:kv = CreateKeyValues("jumps_parachute");
	if (FileToKeyValues(kv, "cfg/vip/modules/jumps_parachute/jumps_parachute.txt"))
	{
		for (new VipModule:module; module < VipModule; module++)
		{
			if (KvGetNum(kv, ITEM_NAME[module]) == 1)
			{
				if (!(g_ItemID[module] = VIP_RegisterItem(ITEM_NAME[module], VIP_ITEM_TOGGLE))) {
					SetFailState("VIP_RegisterItem error (%s)", ITEM_NAME[module]);
				}
				ok = true;
			}
		}
	}
	CloseHandle(kv);
	if (!ok) {
		SetFailState("Check cfg/vip/modules/jumps_parachute/jumps_parachute.txt");
	}
	//

	LoadTranslations("vip_modules_description.phrases");
	wS_ServerVars();

	VIP_HookEvent(VE_Spawn,			OnClientSpawn);
	VIP_HookEvent(VE_Authorized,	OnClientAuthorizeD);

	HookEvent("player_death",		NoRunCmd,	EventHookMode_Pre);
	HookEvent("player_team",		NoRunCmd,	EventHookMode_Pre);
	HookEventEx("round_prestart",	NoRunCmd,	EventHookMode_Pre);
	HookEvent("round_start",		NoRunCmd,	EventHookMode_Pre);
	HookEvent("round_freeze_end",	GoRunCmd,	EventHookMode_Post);
}

///////////////////////////////////////////////////////////////////////////////////

public bool:VIP_CurrentItemValue(client, ItemID, String:ItemValue[], ItemValueSize)
{
	new VipModule:module = wS_ItemIDToModule(ItemID);
	if (g_bAccess[client][module])
	{
		IntToString(g_bAccess[client][module], ItemValue, ItemValueSize);
		return true;
	}
	ItemValue[0] = 0;
	return false;
}

public bool:VIP_Description(client, ItemID, String:ItemValue[ITEM_INFO_LENGTH], String:description[], description_size)
{
	FormatEx(description, description_size, "%T", ITEM_NAME[wS_ItemIDToModule(ItemID)], client, StringToInt(ItemValue));
	return true;
}

public VipGiveAction:VIP_GiveAccess(client, ItemID, String:ItemValue[ITEM_INFO_LENGTH], bool:bCallAfterAdminAction, CURRENT_ACCESS, Handle:kv)
{
	new VipModule:module = wS_ItemIDToModule(ItemID);
	
	// есть значение
	if (module == air_jumps) {
		return UpdateAccess(client, ItemValue, module);
	}
	
	// нет
	if (g_bAccess[client][module]) { return VGA_AlreadyEnabled; }
	g_bAccess[client][module] = 1;
	if (IsPlayerAlive(client)) { wS_RunCmd(client); }
	VIP_NotifyItemStatusChanged(client, ITEM_NAME[module], true);
	
	return VGA_Continue;
}

public VIP_TakeAccess(client, ItemID, bool:bToggledByClient)
{
	new VipModule:module = wS_ItemIDToModule(ItemID);
	
	if (module == air_jumps) { g_AirJumpsLeft[client] = 0; }
	else if (module == parachute) { wS_ClearParachute(client); }
	
	if (!bToggledByClient && g_bModuleForAll[module] && !(VIP_GetItemFlags(g_ItemID[module]) & VIP_ITEM_MAPDISABLED))
	{
		g_bAccess[client][module] = 1;
		if (module == air_jumps) { g_AirJumpsLeft[client] = 1; }
	}
	else {
		g_bAccess[client][module] = 0;
	}
	
	if (IsPlayerAlive(client)) { wS_RunCmd(client); }
	VIP_NotifyItemStatusChanged(client, ITEM_NAME[module], false);
}

stock VipGiveAction:UpdateAccess(client, String:ItemValue[ITEM_INFO_LENGTH], VipModule:module)
{
	if (!ItemValue[0]) {
		return VGA_ValueNotSpecified;
	}
	
	new value = StringToInt(ItemValue);
	if (value < 1) {
		return VGA_BadValue;
	}
	
	if (value > 99999) {
		value = 99999;
	}
	
	if (value == g_bAccess[client][module]) {
		return VGA_SameValue;
	}
	
	g_bAccess[client][module] = value;
	g_AirJumpsLeft[client] = value;
	
	if (IsPlayerAlive(client)) {
		wS_RunCmd(client);
	}
	
	IntToString(value, ItemValue, ITEM_INFO_LENGTH);
	VIP_NotifyItemStatusChanged(client, ITEM_NAME[module], true, ItemValue, 16);

	return VGA_Continue;
}

///////////////////////////////////////////////////////////////////////////////////

static VipModule:wS_ItemIDToModule(ItemID)
{
	for (new VipModule:module = VipModule:0; module < VipModule; module++)
	{
		if (g_ItemID[module] == ItemID) {
			return module;
		}
	}
	return VipModule:0;
}

public OnClientAuthorizeD(client, const String:steamid[], bool:vip)
{
	for (new VipModule:module; module < VipModule; module++)
	{
		if (g_bModuleForAll[module] && g_ItemID[module] && !VIP_HaveAccessToItem(client, g_ItemID[module]) && !(VIP_GetItemFlags(g_ItemID[module]) & VIP_ITEM_MAPDISABLED))
		{
			g_bAccess[client][module] = 1;
			if (VipModule:module == air_jumps) { g_AirJumpsLeft[client] = 1; }
			if (IsPlayerAlive(client)) { wS_RunCmd(client); }
		}
	}
}

public OnClientSpawn(client, team) {
	wS_RunCmd(client);
}

public OnClientDisconnect(client)
{
	g_bRunCmd[client] = false;
	for (new VipModule:module; module < VipModule; module++) {
		g_bAccess[client][module] = 0;
	}
	g_AirJumpsLeft[client] = 0;
	wS_ClearParachute(client);
}